@@ -3,6 +3,6 @@
 QUEUEDIR=$HOME/.msmtpqueue
 
 for i in $QUEUEDIR/*.mail; do
-	egrep -s -h '(^From:|^To:|^Subject:)' "$i" || echo "No mail in queue";
+	grep -E -s          -h '(^From:|^To:|^Subject:)' "$i" || echo "No mail in queue";
 	echo " "
 done
